@@ -3,6 +3,6 @@ from .config import StrConfig,BoolConfig,get_hconfigs,get_hdomains,hconfig,hdoma
 
 from .domain import Domain,DomainType,ShowDomain
 from .proxy import Proxy
-from .user import User,UserMode
+from .user import User,UserMode,is_user_active,remaining_days,days_to_reset
 from .child import Child
-from .parent_domain import ParentDomain
\ No newline at end of file
+from .parent_domain import ParentDomain
